<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:my="http://blog.matfyz.sk"
	xmlns:func="http://exslt.org/functions"
	extension-element-prefixes="my func">
	
	<xsl:param name="lang" />
	
  <xsl:variable name="Lang">
    <xsl:choose>
      <xsl:when test="$lang='ensk'">en</xsl:when>
      <xsl:otherwise><xsl:value-of select="$lang" /></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  <xsl:variable name="StringFile" select="document('./translations/pages.xml')"/>
  <xsl:variable name="StringFileDefault" select="document('./translations/layout.xml')"/>

<func:function name="my:urlpostfix">
  <xsl:param name="what" />
  <xsl:variable name="up" select="'ABCDEFGHIJKLMNOPQRSTUVWXYZ'"/>
  <xsl:variable name="lo" select="'abcdefghijklmnopqrstuvwxyz'"/>
  <xsl:variable name="space" select="'_ ?.!:=-()/'"/>
  <xsl:variable name="other" select="'          '"/>
  <xsl:variable name="dia" select="'áéíóuýčďľĺňôöřšťž'"/>
  <xsl:variable name="nor" select="'aeiouycdllnoorstz'"/>
  <xsl:variable name="diab" select="'ÁÉÍÓÚÝČĎĽĹŇÔŘŠŤŽ'"/>
  <xsl:variable name="norb" select="'aeiouycdllnorstz'"/>
  <func:result>
    <xsl:value-of select="
    translate(
      normalize-space(
        translate(
          translate(
       	   translate(
          	  translate(
                $what, $up, $lo
          	  ), $space, $other
        	   ), $dia, $nor
          ), $diab, $norb
    	  )
      ), ' ', '-'
    )" />
  </func:result>
</func:function>

<xsl:template name="getString">
  <xsl:param name="stringName"/>
  <xsl:variable name="str" 
     select="$StringFile/strings/str[@name=$stringName]"/>
  <xsl:choose>
    <xsl:when test="$str[lang($Lang)]">
      <xsl:value-of select="$str[lang($Lang)][1]"/>
    </xsl:when>
    <xsl:when test="$str[lang($PrimaryLang)]">
      <xsl:value-of select="$str[lang($PrimaryLang)][1]"/>
    </xsl:when>
    <xsl:when test="$str">
      <xsl:value-of select="$str[1]"/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:message terminate="no">
        <xsl:text>Warning: no string named '</xsl:text>
        <xsl:value-of select="$stringName"/>
        <xsl:text>' found.</xsl:text>
      </xsl:message>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="getStringDefault">
  <xsl:param name="stringName"/>
  <xsl:variable name="str" 
     select="$StringFileDefault/strings/str[@name=$stringName]"/>
  <xsl:choose>
    <xsl:when test="$str[lang($Lang)]">
      <xsl:value-of select="$str[lang($Lang)][1]"/>
    </xsl:when>
    <xsl:when test="$str[lang($PrimaryLang)]">
      <xsl:value-of select="$str[lang($PrimaryLang)][1]"/>
    </xsl:when>
    <xsl:when test="$str">
      <xsl:value-of select="$str[1]"/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:message terminate="no">
        <xsl:text>Warning: no string named '</xsl:text>
        <xsl:value-of select="$stringName"/>
        <xsl:text>' found.</xsl:text>
      </xsl:message>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

</xsl:stylesheet>