<?php
/************************************************************************
  		
**************************************************************************/

require_once "include.php";


/**
 * @author Anton Kohutovic 	
 * class existDBapi
 * Trieda implementujuca NXDapi pre preacu sa NXD, zalozena na aplikacii eXist
 * (http://exist.sourceforge.net/).
 */
class ExistDBapi
      implements NXDapi
{


  /**
   * Kod poslednej chyby vratenej z NXD.
   * @access private
   */
  private $error;

  /**
   * Posledny vykonany dotaz
   * @access private
   */
  private $query;
  private $exist;
  private $result;
  private $user;
  Private $password;
  private $logFile;
   
  

 /**
   * Konstruktor
   * @param string user 
   * @param string password 
   * @param string wsdl adresa spojenia na eXist
   * @access public
   */
  public function __construct($debug = false, $logFile = "exist.log")
  {
    $this->logFile = $logFile;
    $this->debug   = $debug;
    return true;
  } // end of constructor
  
  /**
   * Pripojenie do DB
   * @param string user 
   * @param string password 
   * @return bool
   * @access public
   */
  public function connect($user, $password) 
  {
   try
   {
      $this->exist = new eXist($user, $password);
   }
   catch (Exception $e)
   {
      $this->failure("Initialization error", $e);
   }
    if ($this->exist->connect()) return true;
    else $this->failure("Connection error");
   } // end of member function connect

  /**
   * Vykona dotaz na DB
   * @param string query 
   * @return 
   * @access public
   */
  public function execute($query)
  {
    $this->error=null;
    $this->result = $this->exist->xquery($query);
    if (!$this->result)
    {
      $this->error=$this->exist->getError();
      $this->failure($this->error);
    }
    return $this->result;
  } // end of member function execute

  /**
   *
   * @param string query 
   * @return 
   * @access public
   */
  public function fetchArray($query)
  {
    $this->execute($query);
    return $this->result['XML'];
  } // end of member function fetchArray

  /**
   * Nataha Node z DB
   * @param string query 
   * @return 
   * @access public
   */
  public function fetchNode($query)
  {
    $this->execute($query);
    if (is_array($this->result['XML'])) return implode("\n",$this->result['XML']);
    else return $this->result['XML'];
  } // end of member function fetchNode

  /**
   * Vrati poslednu chybu
   * @return 
   * @access public
   */
  public function getError()
  {
    return $this->exist->getError();
  } // end of member function getError
  
  /**
   * Vrati cas spracovania posledneho vysledku
   * @return 
   * @access public
   */
  public function getQueryTime()
  {
    return $this->result["QUERY_TIME"];
  } // end of member function getQueryTime
  
  /**
   * Vrati kolekciu kam smeroval posledny dotaz
   * @return 
   * @access public
   */
  public function getCollection()
  {
    return $this->result["COLLECTIONS"];
  } // end of member function getQueryTime
  
  /**
   * Zobrazi alebo iba zapise do logu vzniknutu chybu.
   * @access private
   */
  private function failure($message,$e=null)
  {
    if (!$logFile=fopen($this->logFile,"a")); 
    fwrite($logFile, strftime("%d.%m.%y %H:%M:%S",time()).": ".$message."\n");
    fclose($logFile);
    if ($this->debug) 
    {
      echo "<br />";
      echo "eXist ERROR: ",$message,"<br />";
      echo "Exception: ";
      var_dump($e);
      echo "<br />";
    }
    return true;
  }



} // end of existDBapi
?>
