<?php
	define('EPSILON', 1.0e-8);

class Graph{
	public $nodes;
	public $nodeCount=0;
	public $edges=array();
	public $edgeCount=0;
	public $iterations = 0; //for debugging
	public $generationTime = "co ja viem";
	public $debug;
	function __construct(){
	}
	public function addNode($name,$mass = 0, $static = false){
		$this->nodes[$name] = new GraphNode($name,$mass, $static);
		$this->nodeCount++;
	}
	public function hasNode($nodeName){
		return isset($this->nodes[$nodeName]);
	}
	public function addEdge($node1,$node2,$length=-1,$strength=-1){
		if (($this->nodes[$node1]!=null)&&($this->nodes[$node2]!=null)){
			foreach($this->edges as $edge){
				if ((($edge->nodes[0]->name==$node1)&&($edge->nodes[1]->name==$node2))||(($edge->nodes[0]->name==$node2)&&($edge->nodes[1]->name==$node1))) return;
			}
			$edge = new GraphEdge($this->edgeCount,$this->nodes[$node1], $this->nodes[$node2],$length,$strength);
			$this->edges[$this->edgeCount] = $edge;
			$this->nodes[$node1]->addEdge($edge);
			$this->nodes[$node2]->addEdge($edge);
			$this->edgeCount++;
		}else {
			//echo("error, node doesn't exist\n");
		}
	}
	public function randomize(){
		foreach ($this->nodes as &$node){
			$node->x= rand(0,10000)/10000;
			$node->y= rand(0,10000)/10000;
		}
	}
	public function makeCircle(){
		$numNodes=count($this->nodes)-1;
		$i=0;
		foreach ($this->nodes as &$node){
			if ($node->static==false){
				$node->x = cos(2*M_PI*$i/$numNodes);
				$node->y = sin(2*M_PI*$i/$numNodes);
				$i++;
			}	
		}
	}
	
	public function normalize(){
		$Xmin = 1; $Xmax = 0;
		$Ymin = 1; $Ymax = 0;
		foreach ($this->nodes as &$node){
			$Xmin = min($node->x,$Xmin);$Xmax = max($node->x,$Xmax);
			$Ymin = min($node->y,$Ymin);$Ymax = max($node->y,$Ymax);
		}
		$dx = $Xmin-(1-($Xmax-$Xmin))/2;
		$dy = $Ymin-(1-($Ymax-$Ymin))/2;
		if (($Xmin==$Xmax)&&($Ymin==$Ymax)){ //one node situation
			$this->nodes[0]->x = 0.5;
			$this->nodes[0]->y = 0.5;
		}else
		foreach ($this->nodes as &$node){
			$node->x -= $Xmin; 
			$node->y -= $Ymin;
			$node->x *= 1/($Xmax-$Xmin+1); //min can be equal to max
			$node->y *= 1/($Ymax-$Ymin+1);
		}
	}
	
	public function make(){
		$energy = 1;
		$x = 2;
		$start=microtime(true);
		while(($energy>0.9)&&($x<200)){
			$energy = $this->step(0.1);
			$x++;
			$this->debug.="\n\n iteration #".$x." energy: ".$energy."\n";
			foreach ($this->nodes as &$node){
				$this->debug.=$node->name.":[".$node->position[0].",".$node->position[1]."]\n";
			}
			
		}
		$end=microtime(true);
		$this->generationTime = $end-$start;
		$this->iterations = $x;
	}
	public function step($time = 0.1){
		$damping = 0.9;
		$totalEnergy = 0;
		foreach ($this->nodes as &$node){
			$velocity = array(0,0);
			foreach($this->nodes as $otherNode){
				if ($otherNode!==$node){
					$tmpVelocity = $this->coulombRepulsion($node,$otherNode);
					$velocity[0] += $tmpVelocity[0];
					$velocity[1] += $tmpVelocity[1];					
				}
			}
			foreach($node->edges as $edge){
				$tmpVelocity = $this->hookeAttraction($edge,$node);
				$velocity[0] += $tmpVelocity[0];
				$velocity[1] += $tmpVelocity[1];
			}	
			$node->velocity[0] = ($node->velocity[0] + $time*$velocity[0])*$damping;
			$node->velocity[1] = ($node->velocity[1] + $time*$velocity[1])*$damping;
			$totalEnergy += $node->mass*( pow($node->velocity[0],2)+pow($node->velocity[1],2) );
			
		}
		foreach ($this->nodes as &$node){
			if (!$node->static) {
				$node->x = ($node->x + $time*$node->velocity[0]);
				$node->y = ($node->y + $time*$node->velocity[1]);
			}
		}
		return($totalEnergy);
	}
	
	public function coulombRepulsion($node1,$node2){
		$distance = max(sqrt(pow($node1->x-$node2->x,2)+pow($node1->y-$node2->y,2)),EPSILON);
		$r[0] = ($node1->x - $node2->x)/pow($distance,2)*($node1->mass*$node2->mass);
		$r[1] = ($node1->y - $node2->y)/pow($distance,2)*($node1->mass*$node2->mass);
		return $r;
	}
	public function hookeAttraction($edge,$node){
		if ($edge->nodes[0]===$node) { $node1 = $edge->nodes[0]; $node2 = $edge->nodes[1];}
			else { $node1 = $edge->nodes[1]; $node2 = $edge->nodes[0];}
		$dlength = sqrt(pow($node1->x-$node2->x,2)+pow($node1->y-$node2->y,2))-$edge->length;
		$distance = max(sqrt(pow($node1->x-$node2->x,2)+pow($node1->y-$node2->y,2)),EPSILON);
		$r[0] = -$edge->strength*($node1->x-$node2->x)/$distance*$dlength;
		$r[1] = -$edge->strength*($node1->y-$node2->y)/$distance*$dlength;	
		return $r;
	}
}


class GraphNode{
	public $name;
	public $mass = 1;
	public $size = 0;
	public $static;
	public $edges = array();
	public $numEdges = 0;
	public $position = array(0,0);
	public $velocity = array(0,0);
	
	private $x=0;//pre __get.. teda php je v tomto dobre nahovno
	private $y=0;
	
	function __construct($name,$mass = 0,$static = false){
		//if ($mass!=0)$this->mass = $mass;
		$this->size = $mass;
		$this->static = $static;
		$this->id = $id;
		$this->name = $name;
	}
	public function __get($what){
		if ($what=='x')return $this->position[0];
		if ($what=='y')return $this->position[1];
		return(47);
	}
	public function __set($what, $value) {
    	if ($what=='x') $this->position[0]=$value;
		if ($what=='y') $this->position[1]=$value;
	}
	
	public function addEdge($edge){
		$this->edges[$this->numEdges++] = $edge;
	}
	public function hasEdgeTo($nodeName){
		foreach($this->edges as &$edge){
			if (($edge->nodes[0]->name==$nodeName)||($edge->nodes[1]->name==$nodeName)) return true;
		}
		return false;
	}
}


class GraphEdge{
	public $id;
	public $nodes;
	public $length=1;
	public $strength = 1;
	function __construct($id,$node1,$node2,$length=-1,$strength=-1){
		if ($length!=-1) $this->length = $length;
		if ($strength!=-1) $this->strength = $strength;
		$this->id = $id;
		$this->nodes = array($node1,$node2);
		
	}

}

?>
