<?php
/**
* This file contains the code for querying NXD Sedna
*
* PHP version 5
*
* @author     Anton Kohutovic
* @license    GPL
*/

/**
* Sednat Class
*
* This class is the main interface for accses to NXD Sedna
*
* @access   public
*/
require_once "NXDapi.php";
require_once "MysqlDB.php";

class Sedna
    implements NXDapi
{
  protected $user     = "guest";
  protected $password = "guest";
  protected $error      = "";
  protected $database;
  protected $hosta;
  protected $result;
  protected $queryTime;
  protected $connection;
  protected $debug=true;
  protected $history = array();
  private $mysql;

  public function __construct($host="localhost", $database="weblog",$user="guest", $password="guest")
  {
    //dl('sedna.so');
    ini_set("sedna.verbosity","1");
    $this->user = $user;
    $this->host = $host;
    $this->password = $password;
    $this->database = $database;
    $this->mysql = new MysqlDB();
 }

  private function myPrint($trace){
	  foreach($trace as $i=>$call){
		  /**
		   * THIS IS NEEDED! If all your objects have a __toString function it's not needed!
		   * 
		   * Catchable fatal error: Object of class B could not be converted to string
		   * Catchable fatal error: Object of class A could not be converted to string
		   * Catchable fatal error: Object of class B could not be converted to string
		   */
		  if (is_object($call['object'])) { $call['object'] = 'CONVERTED OBJECT OF CLASS '.get_class($call['object']); }
		  if (is_array($call['args'])) {
			  foreach ($call['args'] AS &$arg) {
				  if (is_object($arg)) { $arg = 'CONVERTED OBJECT OF CLASS '.get_class($arg); }
			  }
		  }

		  $trace_text[$i] = "#".$i." ".$call['file'].'('.$call['line'].') ';
		  $trace_text[$i].= (!empty($call['object'])?$call['object'].$call['type']:'');
		  $trace_text[$i].= $call['function'].'('.implode(', ',$call['args']).')';
	  }

	  var_dump($trace_text);
  }

  public function __destruct(){
    $this->disconnect();
    if ($GLOBALS['debug'])
    {
      echo '<table style="background-color:yellow;" border="1px"><thead><tr><td>No.</td><td>query</td><td>time</td></tr></thead><tbody>';
      $i = 0;
      $totaltime = 0;
      foreach ($this->history as $q)
      {
      error_reporting(E_ALL);
        echo '<tr><td>', ++$i, '</td><td>';
//	$this->myPrint($q['backtrace']);
	echo htmlspecialchars($q['query']), '</td><td>', $q['time'], '</td></tr>';
        $totaltime += $q['time'];
      }
      echo '<tr><td>*</td><td>total time</td><td>', $totaltime, '</td></tr>';
      echo '</tbody></table>';
    }
  }

  public function disconnect()
  {
    $this->mysql->disconnect();
    if (!$this->connection) return;
    sedna_close($this->connection);
    $this->connection=null;
  }

  public function connect()
  {
    $this->mysql->connect(DBSERVER, DBUSER, DBPASSWORD);
    $this->mysql->selectDB(DBNAME);

    if ($this->connection) return true;	//already connected 
    if ($this->connection=sedna_connect($this->host,$this->database,$this->user,$this->password)) return true;
    else throw new Exception("Sedna error: Connection failed."); 
  }

  public function getError()
  {
      return $this->error;
  }

  public function execute($query)
  {
    $start=microtime(true);
    $return = sedna_execute($query);
    $time = microtime(true)-$start;
    if (DEBUG) $this->history[] = array('query' => $query, 'time' => $time, 'backtrace' => debug_backtrace());
//    $sql = 'INSERT INTO sedna_queries VALUES ("'.addslashes($query).'",'.$time.')';
//    $this->mysql->execute($sql);
    if (!$return){
        debug_print_backtrace();
    	die("Sedna error: ".dumpxml($query).sedna_error());
    }
    return $return;
  }

  public function fetchNode($query)
  {
    if (!$this->execute($query)) 
    {
      die($this->getError());
    }
    else
      if (is_array($this->result=sedna_result_array())) return implode("",$this->result);
      else return $this->result;
  }

  public function getQueryTime($formatted=false)
  {
    if ($formatted) return ($this->queryTime/1000)."s";
    else  return $this->queryTime;
  }

  public function fetchArray($query)
  {
    if (!$this->execute($query)) 
    {
      die($this->getError());
    }
    else return $results = sedna_result_array();
  }

}
