<?php

require_once 'classes/Session.php';
require_once 'classes/Controler.php';
require_once 'classes/Portlet.php';
require_once 'classes/Sedna.php';
require_once 'classes/DokuWiki2HTML.php';
require_once 'classes/keyhighlighter.php';
require_once 'classes/Filters.php';
require_once 'classes/SortQueries.php';
require_once 'classes/RankManager.php';
require_once 'functions.php';

class Article implements Portlet {
	
	public function init($params) {
		if (!defined('POST_LIMIT')) define('POST_LIMIT',1);
		switch ($params['type']) {
			case "postView": {
				$this->incPostAccessCount($params);
				break;
			}
			case "vote": {
				$this->changePostVotesCount($params);
				break;
			}
		}
	}
	
	public function getXML($params) {
		$data="";
		$pagePos = array_key_exists("page",$params) ? (int)$params['page'] : 0;
		switch ($params['type']) {
			case "rss": {
				$data = $this->getPosts($params, array(new PublishedFilter(), new PrivateFilter()), $pagePos, POST_LIMIT, new SimpleTimeSortQuery());
				break;
			}
			case "search": {
				$data = $this->getPosts($params, array(new PublishedFilter(), new SearchFilter(), new LangFilter(), new TopicFilter(), new TagFilter()), $pagePos, POST_LIMIT, new ReputationSortQuery());
				break;
			}
			case "blogView": {
				$data = $this->getPosts($params, array(new PublishedFilter(), new SearchFilter(), new LangFilter(), new TopicFilter(), new TagFilter(), new UserFilter()), $pagePos, POST_LIMIT, new SimpleTimeSortQuery());
				break;
			}
			case "vote":
			case "postView": {
				$data = $this->getPosts($params, array(new PublishedFilter(), new UserFilter(), new ArticleFilter()), 0, 1, new NoSortQuery());
				break;
			}
			case "portalView": {
				$data = $this->getPosts($params, array(new PublishedFilter(), new PrivateFilter(), new LangFilter()), $pagePos, POST_LIMIT, new RecommendedSortQuery());
				break;
			}
			case "userPosts": {
				$sort = new SimpleTimeSortQuery();
				if (isset($params['sort']))
					switch ($params['sort']){
						case "name":{
							$sort = new TitleSortQuery();
							break;
						}
						case "views":{
							$sort = new VisitorsSortQuery();
							break;
						}
						case "react":{
							$sort = new CommentsSortQuery();
							break;
						}
					}
				$data = $this->getPosts($params, array(new LangFilter(), new TagFilter(), new UserFilter()), 0, 'count($all)', $sort);
				break;
			}
			default: {
				return "";
			}
		}
		
		$dokuWiki = new DokuWiki2HTML();
		
		$domData = new DOMDocument();
		$domData->loadXML($data);
		
		$tmpData = new DOMDocument();
		
		$xpath = new DOMXPath($domData);
		foreach (array('content','title','subtitle') as $what) {
			$entries = $xpath->query('/module/newPosts/post//' . $what);
			
			foreach ($entries as $entry) {
				$data = htmlspecialchars($entry->nodeValue);
				if ($entry->parentNode->getAttribute("type")!="xhtml") {
					$data = $dokuWiki->formatBlock($data);
				}
				
				if ($params['type']=='search' && isset($params['q'])) {
					$highlighter = new keyhighlighter($params['q'], true, 'my_highlighter');
					$data = $highlighter->highlight($data);
				}
				
				$data = '<'.$what.'>' . $data . '</'.$what.'>';
				
				if ($tmpData->loadXML($data)) {
					$new = $domData->importNode($tmpData->documentElement, true);
					$entry->parentNode->replaceChild($new, $entry);
				} else echo $data;
			}
		}
		/*
		foreach ($domData->getElementsByTagName("post") as $key=>$item){
			if ($item->getAttribute("type")!="xhtml"){
				$tmpData->loadXML("<content>".$dokuWiki->formatBlock($item->getElementsByTagName("content")->item(0)->nodeValue)."</content>");
				$new = $domData->importNode($tmpData->documentElement, true);
				$item->replaceChild($new, $item->getElementsByTagName("content")->item(0));
				//$item->getElementsByTagName("content")->item(0)->nodeValue = $dokuWiki->formatBlock($item->getElementsByTagName("content")->item(0)->nodeValue);
				//$item->getElementsByTagName("title")->item(0)->nodeValue = $dokuWiki->outputFilter($item->getElementsByTagName("title")->item(0)->nodeValue);
				//$item->getElementsByTagName("subtitle")->item(0)->nodeValue = $dokuWiki->outputFilter($item->getElementsByTagName("subtitle")->item(0)->nodeValue);
			}
		}
		*/
		return $domData->saveXML($domData->documentElement, LIBXML_NOXMLDECL);
	}
	
	public function getXSLlist($params) {
		switch($params['type']) {
			case "rss": {
				return array('classes/modules/articleRSS.xsl');
			}
			case "postView": {
				return array('classes/modules/articleOne.xsl');
			}			
			case "portalView":
			case "search":
			case "vote":
			case "blogView": {
				return array('classes/modules/article.xsl');
			}
			case "userPosts":{
				return array('classes/modules/articleManager.xsl');
			}
		}
		return array();
	}
	
	public function getXSLParams($params) {
		return array('postID' => $params['postID'], 'base' => BASE, 'type' => $params['type']);
		//TODO - exportovat do articleOne.xsl tieto parametre
		//return array('loggedUser' => $_SESSION['session']->getUser()->getNick(), 'loggedUserID' => $_SESSION['session']->getUser()->getID(), 'userID' => $params['userID'], 'nick'=>$params['user']);
	}
	
	private function getPosts($params, $filter, $pagePos, $pageCount, $sort) {
		$start = $pagePos * $pageCount + 1;
		$end = ($pagePos + 1) * $pageCount;
		$xquery = '
			let $all := collection("weblog")/user/blog/post';
		foreach ($filter as $key=>$item)
			$xquery .= $item->getQuery($params);
		
		$xquery .= ',
			$list := 
			subsequence(
						for $i in $all
				';
		$xquery .= $sort->getQuery($params);
		$xquery .= ' return $i,'.$start.','.$pageCount.'),
			$last := count($all),
			$posts:=
			(for $current in $list
			let $user := $current/ancestor::user
			return
			<post>{$current/@ID}{$current/@lang}{$current/@accessCount}
				<user>{$user/@ID}{$user/@type}
				{$user/info/nick}
				{$user/info/realName}
				</user>
				{$current/*}
			</post>
			)
			return <module name="Articles"><newPosts last="{$last}" end="'.$end.'" start="'.$start.'">{$posts}</newPosts></module>
		';
		$result = $GLOBALS['system']->getDB()->fetchNode($xquery);
		return $result;
	}

	private function changePostVotesCount($params) {
		if (!isset($params['postID'], $params['userID'], $params['value'])) return;
		if ($params['value']=='1' || $params['value']=='-1')
			$value = intval($params['value']);
		else return;

		$postID = formatText($params['postID'], false);
		$userID = formatText($params['userID'], false);

		$rankManger = new RankManager();
		if (isset($vote) && isset($postID)) $rankManger->voteForPost($postID, $value);
		
		$xquery = "collection('weblog')/user[@ID=".$userID."]/blog/post[@ID='".$postID."']/votes/@count";
		$count = intval($GLOBALS['system']->getDB()->fetchNode($xquery));
		
		if (!$count) $xquery = "update insert <votes count='1'></votes> into collection('weblog')/user[@ID=".$userID."]/blog/post[@ID='".$postID."']";
		else {
			$count += $value; 
			$xquery = "update replace collection('weblog')/user[@ID=".$userID."]/blog/post[@ID='".$postID."']/votes/@count with '".$count."'";
		}
		$GLOBALS['system']->getDB()->fetchNode($xquery); 
	}

	private function incPostAccessCount($params) {
		if (!isset($params['postID'], $params['userID'])) return;


		$postID = formatText($params['postID'], false);
		$userID = formatText($params['userID'], false);
		
		$xquery = "data(collection('weblog')/user[@ID='".$userID."']/blog/post[@ID='".$postID."']/@accessCount)";
		$count = intval($GLOBALS['system']->getDB()->fetchNode($xquery));
		
		$count++;
		$xquery = 'update replace $i in collection("weblog")/user[@ID="'.$userID.'"]/blog/post[@ID="'.$postID.'"]/@accessCount with attribute accessCount {'.$count.'}';
		$GLOBALS['system']->getDB()->fetchNode($xquery); 

//		$xquery = 'update replace $i in collection("weblog")/user[@ID="'.formatText($params['userID'], false).'"]/blog/post[@ID="'.formatText($params['postID'], false).'"]/@accessCount with attribute accessCount {$i+1}';
//		$GLOBALS['system']->getDB()->fetchNode($xquery); 
	}

}

$GLOBALS['controler']->registerPortlet(Article);

?>
