<?php

require_once 'classes/Session.php';
require_once 'classes/Controler.php';
require_once 'classes/Portlet.php';
require_once 'classes/Sedna.php';
require_once 'classes/User.php';
require_once 'settings.php';
require_once 'classes/SimpleOpenID.php';
require_once 'classes/HookManager.php';
require_once 'classes/TagBrowser.php';


class PostActions implements Portlet {
	private $userID;

	public function init($params) {
		//neprihlaseny? ani nas nezaujima
		if (!$_SESSION['session']->getUser()) return;
		
		if (!$_SESSION['session']->getUser()->getUserPermissions('canEditOthersPosts') ||
			!$_SESSION['session']->getUser()->getUserPermissions('canMakeTop'))
			$params['userID'] = $_SESSION['session']->getUser()->getID();
		
		$this->userID = $params['userID'];

		$postID = array_key_exists("postID",$_POST) ? $_POST['postID'] : 0;
		$commentID = array_key_exists("commentID",$_POST) ? $_POST['commentID'] : 0;
		$title = array_key_exists("title",$_POST) ? $_POST['title'] : "";
		$comment = array_key_exists("comment",$_POST) ? $_POST['comment'] : "";
		$content = array_key_exists("postContent",$_POST) ? $_POST['postContent'] : "";
		$tags = array_key_exists("tags",$_POST) ? explode(",",$_POST['tags']) : "";
		$description = array_key_exists("description",$_POST) ? $_POST['description'] : "";
		$subtitle = array_key_exists("subtitle",$_POST) ? $_POST['subtitle'] : "";
		$language = array_key_exists("language",$_POST) ? $_POST['language'] : "";
		$status = array_key_exists("status",$_POST) ? $_POST['status'] : "";
		$private = array_key_exists("private",$_POST) ? (bool)$_POST['private'] : false;
		
		/* Zmena $statuso a $private kvoli radiobuttonom v newPost/editPost */		
		$postStatus = array_key_exists("postStatus",$_POST) ? $_POST['postStatus'] : "";
		if ($postStatus == 'notPrivate') {
			$status = 'published';
			$private = false;
		}	elseif ($postStatus == 'private') {
			$status = 'published';
			$private = true;
		}	elseif ($postStatus == 'asDraft') {
			$status = 'draft';
			$private = false;		
		}
		
		if (isset($_POST['deletePost']))
			$this->deletePost($postID);

		if (isset($_POST['changePostStatus']))
			$this->setStatus($postID, $status);

		if (isset($_POST['editPost']))
			if ($postID!=''){
				$this->editPost($postID, $title, $content, $tags, $description, $subtitle, $language, $status, $private);
			} else {
				$this->newPost($title, $content, $tags, $description, $subtitle, $language, $status, $private);
			}

		if (isset($_POST['makeTop']))
			$this->makeTop($postID);

		if (isset($_POST['makeTopOut']))
			$this->makeTopOut($postID);
	}
	
	public function getXML($params) {
		//neprihlaseny? ani nas nezaujima
		if (!$_SESSION['session']->getUser()) return "";
		
		//tu generovat XML s postom pri edite
		$data="";
		
		switch($params['type']) {
			case "postForm": {
				if (isset($params['postID'])){
					$data = '<module name="PostActions">';
					$data .= $this->getPost($params, array(new UserFilter($params), new ArticleFilter($params)));
					$data .= '</module>';
				} else {
					$data = '<module name="PostActions"></module>';
				}
				break;
			}
			case "postView":{
				$data = '<module name="PostActions">';
				if ($_SESSION['session']->getUser()->getUserPermissions('canEditOthersPosts') ||
					$params['userID'] == $_SESSION['session']->getUser()->getID())
					$data .= '<editButton/><deleteButton/>';

				if ($_SESSION['session']->getUser()->getUserPermissions('canMakeTop'))
					$data .= '<makeTop/><makeTopOut/>';
				$data .= '</module>';
				break;
			}
			case "userPosts":{
				$data = '<module name="PostActions">';
				$data .= '<makeNewPost/>';
				$data .= '</module>';
				break;
			}
		}
		return $data;
	}
	
	public function getXSLlist($params) {
		//neprihlaseny? ani nas nezaujima
		if (!$_SESSION['session']->getUser()) return array();
		
		//tu generovat postForm

		switch($params['type']) {
			case "postForm": {
				return array('classes/modules/postForm.xsl');
				break;
			}
			case "userPosts":
			case "postView":{
				return array('classes/modules/postActions.xsl');
				break;
			}
		}
		return array();
	}
	
	public function getXSLParams($params) {
		//neprihlaseny? ani nas nezaujima
		if (!$_SESSION['session']->getUser()) return array();
		
		switch($params['type']) {
			case "postForm":
 			case "postView":{
				return array('postID' => $params['postID'], 'base' => BASE, 'user' => $params['user']);
				break;
			}
		}
		
		return array();
	}
		
	private function makeTop($postID){
		//zaradi post medzi Top posty kvoli titulke
		$xquery = 'update delete collection("weblog")/user/blog/post[@ID="'.formatText($postID, false).'"]/dateTop';
		$GLOBALS['system']->getDB()->fetchNode($xquery);
		$xquery = 'update delete collection("weblog")/user/blog/post[@ID="'.formatText($postID, false).'"]/dateTopOut';
		$GLOBALS['system']->getDB()->fetchNode($xquery);
		
		$xquery='update insert
			<dateTop timestamp="'.time().'">'.date("Y-m-d\TH:i:s").'</dateTop>
		into collection("weblog")/user/blog/post[@ID="'.formatText($postID, false).'"]';
		$GLOBALS['system']->getDB()->fetchNode($xquery);

		$xquery='let $lang:=collection("weblog")/user/blog/post[@ID="'.formatText($postID, false).'"]/@lang
				return data(
				subsequence(
					for $i in collection("weblog")/user/blog/post[dateTop][not(dateTopOut)][@lang=$lang]
						order by $i/date/@timestamp descending
					return $i/@ID,6,1
				)
			)';
		$post=$GLOBALS['system']->getDB()->fetchNode($xquery);

		if ($post){
			$this->makeTopOut($post);
		}
	}

	private function makeTopOut($postID){
		//post zostane TOP ale uz bude vyradeny
		$xquery = 'update delete collection("weblog")/user/blog/post[@ID="'.formatText($postID, false).'"]/dateTopOut';
		$GLOBALS['system']->getDB()->fetchNode($xquery);

		$xquery='update insert
			<dateTopOut timestamp="'.time().'">'.date("Y-m-d\TH:i:s").'</dateTopOut>
			into collection("weblog")/user/blog/post[@ID="'.formatText($postID, false).'"][dateTop]';
		$GLOBALS['system']->getDB()->fetchNode($xquery);
	}

	/**
	*
	* @return 
	* @access public
	*/
	private function newPost($title, $content, $tags, $description="", $subtitle="", $language="sk", $status='published', $private=true)
	{
		
			//ak nie su vyplnene nadpis a zvoleny stav prispevku (published+na titulke/published+private/draft) tak sa vrat na formular a vypis upozornenie
			/*
			if ($title == "" or $postStatus == NULL) {
				if ($title == '') {$noTitle = 1;} else {$noTitle = 0;}
				if ($postStatus == NULL) {$noStatus = 1;} else {$noStatus = 0;}
				$parametre = array("noTitle"=>$noTitle, "noStatus"=>$noStatus);
				redirect("http://".$_SESSION['session']->getUser()->getNick().".".BASE."/newpost", $parametre);
			}
			*/
		//platne statusy su len published a draft
		if ($status!='published' && $status!='draft') return;
	
		
		$max = $GLOBALS['system']->getMaxID();
		
		//pridanie novych tagov
		$tb = new TagBrowser("");
		if (is_array($tags))
		foreach ($tags as $tag){$tb->addTag($tag,$language);}
		
		$tagsXML = "";
		if (is_array($tags))
		foreach ($tags as $tag)
		{
			$tagsXML .= '<tag>'.formatText(trim($tag)).'</tag>';
		}
		
		if ($private==true) $private="yes";
		else $private="no";

		$query = 'update insert
			<post ID="p'.($max+1).'" accessCount="0" lang="'.formatText($language).'" status="'.formatText($status).'" private="'.formatText($private).'">
			<title>'.formatText($title).'</title>
			<subtitle>'.formatText($subtitle).'</subtitle>
			<content> '.formatText($content).' </content>
			<tags>'.$tagsXML.'</tags>
			<date timestamp="'.time().'">'.date("Y-m-d\TH:i:s").'</date>
			<comments/>
		<topics/>
			</post>
			into collection("weblog")/user[@ID="'.$this->userID.'"]/blog';
		if ($GLOBALS['system']->getDB()->fetchNode($query)) return "p".($max+1);
	} // end of member function newPost
	
	
	private function editPost($id,$title, $content, $tags, $description="", $subtitle="", $language='sk', $status='published', $private=true){
		if (strtolower($status)=='reset') $status='published' ; // riadi sa to podla buttonov, a je tam aj button reset, a taky stav nechceme;
		//platne statusy su len published a draft
		if ($status!='published' && $status!='draft') return;

		//pridanie novych tagov
		$tb = new TagBrowser("");
		if (is_array($tags))
		foreach ($tags as $tag){$tb->addTag($tag,$language);}
			
		
		$tagsXML = "";
		if (is_array($tags))
		foreach ($tags as $tag)
			$tagsXML .= '<tag>'.formatText(trim($tag)).'</tag>';

		if ($private==true) $private="yes";
		else $private="no";

		$query = 'update replace $i in collection("weblog")/user[@ID="'.$this->userID.'"]/blog/post[@ID="'.$id.'"]
			with
		if ($i/@type) then
			<post ID="'.formatText($id).'" accessCount="{$i/@accessCount+1}" lang="'.formatText($language).'" status="'.formatText($status).'" private="'.formatText($private).'">
			{$i/@type}
			{$i/@submitted}
			<title>'.formatText($title).'</title>
			<subtitle>'.formatText($subtitle).'</subtitle>
		<content> '.formatText($content).' </content>
			<tags>'.$tagsXML.'</tags>
			<lastUpdate timestamp="'.time().'">'.date("Y-m-d\TH:i:s").'</lastUpdate>
			{$i/date}
			{$i/comments}
		{$i/dateTop}
		{$i/dateTopOut}
			<topics/>
			</post>
		else
		<post ID="'.($id).'" accessCount="{$i/@accessCount+1}" lang="'.formatText($language).'" status="'.formatText($status).'" private="'.formatText($private).'">
			{$i/@type}
			{$i/@submitted}
			<title>'.formatText($title).'</title>
			<subtitle>'.formatText($subtitle).'</subtitle>
		<content> '.formatText($content).' </content>
			<tags>'.$tagsXML.'</tags>
			<lastUpdate timestamp="'.time().'">'.date("Y-m-d\TH:i:s").'</lastUpdate>
			{$i/date}
			{$i/comments}
			{$i/topics}
		{$i/dateTop}
		{$i/dateTopOut}
			</post>';
			
		$GLOBALS['system']->getDB()->fetchNode($query);
	}
	
	private function setStatus($id, $status){
		if (strtolower($status)=='reset') return ; // riadi sa to podla buttonov, a je tam aj button reset, a taky stav nechceme;
		//platne statusy su len published a draft
		if ($status!='published' && $status!='draft') return;

		$currentStatus =  $GLOBALS['system']->getDB()->fetchNode('collection("weblog")/user/blog/post[@ID="'.formatText($id, false).'"]/@status/normalize-space()');
		if ($status=='published' && $currentStatus=="draft")
		{ 
		$xquery = 'update replace $i in collection("weblog")/user/blog/post[@ID="'.formatText($id, false).'"]/date with  <date timestamp="'.time().'">'.date("Y-m-d\TH:i:s").'</date>';
		$GLOBALS['system']->getDB()->fetchNode($xquery);
		}

		$xquery = 'update replace $i in collection("weblog")/user/blog/post[@ID="'.$id.'"]/@status
			with attribute status {"'.formatText($status).'"}';
		$GLOBALS['system']->getDB()->fetchNode($xquery);
	}

	private function deletePost($postID){
		$query = 'update delete collection("weblog")/user[@ID="'.$this->userID.'"]/blog/post[@ID="'.formatText($postID, false).'"]';
		$GLOBALS['system']->getDB()->fetchNode($query);
	}
	
	public function getPost($params, $filter)
	{
		$xquery = 'collection("weblog")/user/blog/post';
		foreach ($filter as $key=>$item)
			$xquery .= $item->getQuery($params);

		return $GLOBALS['system']->getDB()->fetchNode($xquery);
		//dumpxml($this->xml);
	}
}

$GLOBALS['controler']->registerPortlet(PostActions);

?>
