<?xml version="1.0" encoding="utf8"?>
<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:func="http://exslt.org/functions"
                xmlns:date="http://exslt.org/dates-and-times"
                xmlns:math="http://exslt.org/math"
                xmlns:my="http://blog.matfyz.sk"
                exclude-result-prefixes="math xsl"
                extension-element-prefixes="my func date math">
  <xsl:import href="layout.xsl" />
  <xsl:output omit-xml-declaration="no" method="xml" doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd" indent="yes" encoding="utf-8" />
  <xsl:variable name="userID" select='/user/@ID' />
  <xsl:variable name="title" select='/user/blog/title' />
  <xsl:variable name="subtitle" select='/user/info/nick' />
  <xsl:variable name="nick" select='/user/info/nick' />
  <xsl:variable name="blogTitle" select='$title' />
  <xsl:variable name="blogURL" select="concat('http://',$nick,'.',$base)" />
  <xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
  <xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
  <xsl:param name="tag" />
  <xsl:param name="sort" />
  <xsl:param name="order" />
  <xsl:variable name="description" select="//info/about" />
  <xsl:variable name="keywords">
    <xsl:for-each select="//tags/tag[not(. = preceding::tag)]">
      <xsl:value-of select="." />, 
    </xsl:for-each>
  </xsl:variable>
  
  <xsl:template match="/">
    <xsl:apply-imports />
  </xsl:template>

<xsl:template match="/user">
  <div id="left">
    <div class="cpad">
      <span id="activesort" title="date" />
      <span id="activeorder" title="desc" />
      <xsl:variable name="sortOrder">
        <xsl:choose>
          <xsl:when test="$order = 'asc'">ascending</xsl:when>
          <xsl:when test="$order = 'desc'">descending</xsl:when>
          <xsl:otherwise>ascending</xsl:otherwise>
        </xsl:choose>
      </xsl:variable>
      <xsl:variable name="catUrl">
        <xsl:choose>
          <xsl:when test="$tag">?tag=<xsl:value-of select="$tag" /></xsl:when>
          <xsl:otherwise></xsl:otherwise>
        </xsl:choose>
      </xsl:variable>
      <p id="sortList">
        <xsl:call-template name="getString">
          <xsl:with-param name="stringName" select="'Sort by'"/>
        </xsl:call-template>:
        <a href="{$blogURL}/sort-name-{my:sort('name',$sort,$order)}{$catUrl}" class="{my:sortclass('name',$sort,$order)}"><xsl:call-template name="getString">
          <xsl:with-param name="stringName" select="'Alphabet'"/>
        </xsl:call-template></a>
        <a href="{$blogURL}/sort-views-{my:sort('views',$sort,$order)}{$catUrl}" class="{my:sortclass('views',$sort,$order)}"><xsl:call-template name="getString">
          <xsl:with-param name="stringName" select="'View count'"/>
        </xsl:call-template></a>
        <a href="{$blogURL}/sort-react-{my:sort('react',$sort,$order)}{$catUrl}" class="{my:sortclass('react',$sort,$order)}"><xsl:call-template name="getString">
          <xsl:with-param name="stringName" select="'Reactions'"/>
        </xsl:call-template></a>
        <a href="{$blogURL}/sort-date-{my:sort('date',$sort,$order)}{$catUrl}" class="{my:sortclass('date',$sort,$order)}"><xsl:call-template name="getString">
          <xsl:with-param name="stringName" select="'DateSort'"/>
        </xsl:call-template></a>
      </p>
      <div id="posts">
        <xsl:choose>
          <xsl:when test="$sort = 'name'">
            <xsl:apply-templates select="blog/post[((tags/tag=$tag) or not($tag)) and contains($lang,@lang)][@status='published']">
            <xsl:sort select="title" order="{$sortOrder}" />
            <xsl:sort select="@ID" order="descending" data-type="number" />
            </xsl:apply-templates>
          </xsl:when>
          <xsl:when test="$sort = 'views'">
            <xsl:apply-templates select="blog/post[((tags/tag=$tag) or not($tag)) and contains($lang,@lang)][@status='published']">
            <xsl:sort select="@accessCount" order="{$sortOrder}" data-type="number" />
            <xsl:sort select="@ID" order="descending" data-type="number" />
            </xsl:apply-templates>
          </xsl:when>
          <xsl:when test="$sort = 'react'">
            <xsl:apply-templates select="blog/post[((tags/tag=$tag) or not($tag)) and contains($lang,@lang)][@status='published']">
            <xsl:sort select="count(.//comment)" order="{$sortOrder}" data-type="number" />
            <xsl:sort select="@ID" order="descending" data-type="number" />
            </xsl:apply-templates>
          </xsl:when>
          <xsl:when test="$sort = 'date'">
            <xsl:apply-templates select="blog/post[((tags/tag=$tag) or not($tag)) and contains($lang,@lang)][@status='published']">
            <xsl:sort select="date/@timestamp" order="{$sortOrder}" />
            <xsl:sort select="@ID" order="descending" data-type="number" />
            </xsl:apply-templates>
          </xsl:when>
          <xsl:otherwise>
            <xsl:apply-templates select="blog/post[((tags/tag=$tag) or not($tag)) and contains($lang,@lang)][@status='published']">
            <xsl:sort select="date/@timestamp" order="descending" />
            <xsl:sort select="@ID" order="descending" />
            </xsl:apply-templates>
          </xsl:otherwise>
        </xsl:choose>
      </div>
    </div>
  </div>
  <div id="right">
    <div class="cpad">  
      <xsl:if test="$avatar='true'">
        <div class="wheader f1 f1a">
          <div class="l">
            <div class="t">
              <div class="b">
                <div class="r">
                  <div class="lt">
                    <div class="lb">
                      <div class="rt">
                        <div class="rb wmenu">
                          <div class="avatar">
                            <img src="avatar.jpg" alt="{/user/info/realName}"/>
                            <p><xsl:value-of select="/user/info/realName" /></p>
                          </div>
                        </div>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </xsl:if>
      <h2><xsl:call-template name="getString">
        <xsl:with-param name="stringName" select="'About author'"/>
      </xsl:call-template></h2>
      <div class="aboutnode">
        <span class="bold"><xsl:call-template name="getString">
        <xsl:with-param name="stringName" select="'Authority'"/>
      </xsl:call-template>: </span> <xsl:value-of select="/user/info/ranks/authorityScore" />
        
        <div class="formatted">
          <xsl:copy-of select="/user/info/about/node()" />
         
        </div>
      </div>
      <div class="tagCloud">
        <h2><xsl:call-template name="getString">
          <xsl:with-param name="stringName" select="'Tags'"/>
        </xsl:call-template></h2>
        <a href="./"><xsl:call-template name="getString">
          <xsl:with-param name="stringName" select="'All'"/>
        </xsl:call-template> (<xsl:value-of select="count(/user/blog/post)" />)</a><xsl:text>, </xsl:text>
        <xsl:variable name="tags" select="/user/blog/post/tags" />
        <xsl:for-each select="$tags/tag[not(. = preceding::tag)]">
          <xsl:sort select="translate(.,$ucletters,$lcletters)" order="ascending"/>
          <xsl:variable name="curTag" select="." />
          <xsl:variable name="tagClass">
            <xsl:if test="$tag = $curTag">highlightedkey</xsl:if>
            <xsl:if test="not($tag)"></xsl:if>
          </xsl:variable>
          <a href="./?tag={.}" class="{$tagClass}"><xsl:value-of select="."/> (<xsl:value-of select="count(/user/blog/post[.//tag=$curTag])" />)</a>
          <xsl:if test="position() != last()">
            <xsl:text>, </xsl:text>
          </xsl:if>
        </xsl:for-each>
      </div> 
      
      <xsl:if test="//neighbours/neighbour">
      <div>
         <h2><xsl:call-template name="getString">
            <xsl:with-param name="stringName" select="'Neighbours'"/>
          </xsl:call-template></h2>
        <ul>
        <xsl:for-each select="//neighbours/neighbour[position()&lt;11]">
          <xsl:sort select="similarity" order="descending"/>
          <li>
            <a href="http://{info/nick}.{$base}" title="{info/realName}: {info/title}"><xsl:value-of select="info/realName" /></a>
          </li>
        </xsl:for-each>
      </ul>
      </div> 
    </xsl:if>
    
      <h2><xsl:call-template name="getString">
        <xsl:with-param name="stringName" select="'Discussion'"/>
      </xsl:call-template></h2>
      <xsl:for-each select="//post[@status='published']//comment">
        <xsl:sort select="date" />
        <xsl:if test="position()=last()">
          <xsl:copy-of select="substring(content,0,100)" />
          <xsl:if test="string-length(content)>100"> ...</xsl:if>
          <br />
          <ul style="margin-left: 0ex;">
            <li><a href="{$blogURL}/post-{ancestor::post/@ID}"><xsl:value-of select="ancestor::post/title" /></a></li>
            <li><strong><xsl:value-of select="title" /></strong></li>
            <li><xsl:if test="author/@userID">
              <a href="http://{author/nick}.{$base}"><xsl:value-of select="author/realName" /></a>
            </xsl:if>
            <xsl:if test="not(author/@userID)">
              <xsl:value-of select="author" />
            </xsl:if></li>
            <li><xsl:value-of select="substring(date,9,2)" />.
            <xsl:value-of select="substring(date,6,2)" />.
            <xsl:value-of select="substring(date,1,4)" /><xsl:text> </xsl:text>
            <xsl:value-of select="substring-after(date,'T')" /></li>
          </ul>
        </xsl:if>
      </xsl:for-each>
    </div>
  </div>
</xsl:template>

<xsl:template match="comments">
  <div class="status">
    <span>
    	<xsl:call-template name="getString">
        <xsl:with-param name="stringName" select="'Views'"/>
      </xsl:call-template>: <span class="accesscount"><xsl:value-of select="./ancestor::post/@accessCount" /></span>
    	|
      <xsl:call-template name="getString">
        <xsl:with-param name="stringName" select="'Reactions'"/>
      </xsl:call-template>: <span class="react"><xsl:value-of select="count(.//comment)" /></span>
      
       <xsl:if test="./ancestor::post/ranks/reputationScore > 0">
          | 
           <xsl:call-template name="getString">
             <xsl:with-param name="stringName" select="'Score'"/>
           </xsl:call-template>: 
           <xsl:value-of select="./ancestor::post/ranks/reputationScore" />
          </xsl:if>
    </span>
  </div>
</xsl:template>

<xsl:template match="post">
  <div class="post">
    <p class="date">
      <xsl:if test="@lang">
        <img src="./css/flags/{@lang}.png" width="16" height="11" alt="{@lang} flag" class="flag"/>
        |
      </xsl:if>
      <span class="created">
        <xsl:value-of select="substring(date,9,2)" />.
        <xsl:value-of select="substring(date,6,2)" />.
        <xsl:value-of select="substring(date,1,4)" /><xsl:text> </xsl:text>
        <xsl:value-of select="substring(date,12,2)" />:<xsl:value-of select="substring(date,15,2)" />
      </span>
      <xsl:if test="lastUpdate">
        (<xsl:call-template name="getString">
          <xsl:with-param name="stringName" select="'Changed'"/>
        </xsl:call-template>: <xsl:value-of select="substring(lastUpdate,9,2)" />.
        <xsl:value-of select="substring(lastUpdate,6,2)" />.
        <xsl:value-of select="substring(lastUpdate,1,4)" /><xsl:text> </xsl:text>
        <xsl:value-of select="substring(lastUpdate,12,2)" />:<xsl:value-of select="substring(lastUpdate,15,2)" />)
      </xsl:if>
    </p>
    <xsl:variable name="nazov" select="my:urlpostfix(title)" />
    <h2><a href="{$blogURL}/{@ID}-{$nazov}"><xsl:value-of select="title" /><xsl:if test="string-length(subtitle/node()) > 0">: <xsl:copy-of select="subtitle/node()" /></xsl:if></a></h2>
      <xsl:choose>
        <xsl:when test="contains(content,'--break--')">
          <div class="formatted">
            <xsl:copy-of select="substring-before(content/node(),'--break--')" />
          </div>
        </xsl:when>
        <xsl:otherwise>
          <xsl:if test="@type='xhtml'">
            <div class="para">
              <xsl:copy-of select="content/*[1]" />
            </div>
          </xsl:if>
          <xsl:if test="not(/user/@type='student')">
            <div class="formatted">
              <xsl:copy-of select="substring(content/node(),1,150)" />
            </div>
          </xsl:if>
        </xsl:otherwise>
      </xsl:choose>
      <div class="clear"/>
    <a href="{$blogURL}/{@ID}-{$nazov}" class="raquo"><xsl:call-template name="getString">
      <xsl:with-param name="stringName" select="'WholePost'"/>
    </xsl:call-template></a>
    <xsl:apply-templates select="comments" />
  </div>
  <hr />   
</xsl:template>

<func:function name="my:sort">
  <xsl:param name="what" />
  <xsl:param name="sort" />
  <xsl:param name="order" />
  <func:result>
  <xsl:choose>
    <xsl:when test="$what = $sort and $order = 'asc'">desc</xsl:when>
    <xsl:when test="$what = $sort and $order = 'desc'">asc</xsl:when>
    <xsl:otherwise>desc</xsl:otherwise>
  </xsl:choose>
  </func:result>
</func:function>

<func:function name="my:sortclass">
  <xsl:param name="what" />
  <xsl:param name="sort" />
  <xsl:param name="order" />
  <func:result>
  <xsl:choose>
    <xsl:when test="$what = 'date' and $order = ''">desc</xsl:when>
    <xsl:when test="$what = $sort and $order = 'asc'">asc</xsl:when>
    <xsl:when test="$what = $sort and $order = 'desc'">desc</xsl:when>
    <xsl:otherwise></xsl:otherwise>
  </xsl:choose>
  </func:result>
</func:function>

</xsl:stylesheet>