<?xml version="1.0" encoding="utf8"?>
<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:func="http://exslt.org/functions"
                xmlns:date="http://exslt.org/dates-and-times"
                xmlns:math="http://exslt.org/math"
                xmlns:my="http://blog.matfyz.sk"
                exclude-result-prefixes="math xsl"
                extension-element-prefixes="my func date">
  <xsl:import href="layout.xsl" />
  <xsl:output omit-xml-declaration="no" method="xml" doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd" indent="yes" encoding="utf-8" />
  <xsl:variable name="userID" select='/postView/userID' />
  <xsl:variable name="postID" select="/postView/post/@ID" />
  <xsl:variable name="title" select="/postView/post/title" />
  <xsl:variable name="subtitle" select="/postView/post/subtitle" />
  <xsl:variable name="blogTitle" select="/postView/title" />
  <xsl:variable name="nick" select="/postView/info/nick" />
  <xsl:variable name="description" select="substring(normalize-space(/postView/post/content),1, 100)" />
  <xsl:variable name="keywords" select="normalize-space(/postView/post/tags)" />
  <xsl:variable name="blogURL" select="concat('http://',$nick,'.',$base)" />
  
  <xsl:template match="/">
  
    <xsl:apply-imports />
  </xsl:template>


<xsl:template match="postView">
  <div id="left">
  <div class="cpad">
    <xsl:for-each select="post[(@status='published') or ($loggedUser and $loggedUserID = $userID)]">
      <div class="post">
        <p class="date">
          <xsl:if test="@lang">
            <img src="./css/flags/{@lang}.png" width="16" height="11" alt="{@lang} flag" class="flag"/>
            |
          </xsl:if>
          <span class="created">
            <xsl:value-of select="substring(date,9,2)" />.
            <xsl:value-of select="substring(date,6,2)" />.
            <xsl:value-of select="substring(date,1,4)" /><xsl:text> </xsl:text>
            <xsl:value-of select="substring(date,12,2)" />:<xsl:value-of select="substring(date,15,2)" />
          </span>
          <xsl:if test="lastUpdate">
            (<xsl:call-template name="getString">
              <xsl:with-param name="stringName" select="'Changed'"/>
            </xsl:call-template>: <xsl:value-of select="substring(lastUpdate,9,2)" />.
            <xsl:value-of select="substring(lastUpdate,6,2)" />.
            <xsl:value-of select="substring(lastUpdate,1,4)" /><xsl:text> </xsl:text>
            <xsl:value-of select="substring(lastUpdate,12,2)" />:<xsl:value-of select="substring(lastUpdate,15,2)" />)
          </xsl:if>
        </p>
        <h1 class="posting"><xsl:value-of select="title" /></h1>
        <div class="bordering"><xsl:value-of select="subtitle" /></div>
        <div>
       
        <xsl:element name="div">
          <xsl:if test="@type='xhtml'">
            <xsl:attribute name="class">xhtml</xsl:attribute>
          </xsl:if>
          <xsl:if test="not(@type)">
            <xsl:attribute name="class">formatted</xsl:attribute>
          </xsl:if>
          <xsl:copy-of select="content/node()" />
        </xsl:element>
        <a href="javascript:location.href='http://vybrali.sme.sk/submit.php?url='+encodeURIComponent(location.href)" title="vybrali.sme.sk" >
          <img src="http://zena.sme.sk/storm/imgs/toolbar/doasdf_c.gif" alt="pošli na vybrali.sme.sk" border="0"  /> Pošli článok do vybrali.sme.sk</a>
        <xsl:if test="$loggedUser">
        <xsl:if test="$loggedUserID = $userID">
          <br /><br />
            <form action="{$blogURL}/?type=editPostForm" method="get" class="frm">
              <fieldset>
                <input type="hidden" name="type" value="editPostForm" />
                <input type="hidden" name="userID" value="{$userID}" />
                <input type="hidden" name="postID" value="{@ID}" />
                <button class="submit"><xsl:call-template name="getString">
                  <xsl:with-param name="stringName" select="'Edit'"/>
                </xsl:call-template></button>
              </fieldset>
            </form>
            <form action="{$blogURL}/?type=deletePost" method="post" class="frm" onsubmit="return window.confirm('Chcete naozaj zmazať tento príspevok?')">
              <fieldset>
                <input type="hidden" name="type" value="deletePost" />
                <input type="hidden" name="userID" value="{$userID}" />
                <input type="hidden" name="postID" value="{@ID}" />
                <button class="submit"><xsl:call-template name="getString">
                  <xsl:with-param name="stringName" select="'Delete'"/>
                </xsl:call-template></button>
               </fieldset>
            </form>
        </xsl:if>
        </xsl:if>
        <div class="clear"/>
        <div class="status">
        <span>
          <xsl:call-template name="getString">
            <xsl:with-param name="stringName" select="'Views'"/>
          </xsl:call-template>: <span class="accesscount"><xsl:value-of select="@accessCount" /></span>
          |
          <xsl:call-template name="getString">
            <xsl:with-param name="stringName" select="'Reactions'"/>
          </xsl:call-template>: <span class="react"><xsl:value-of select="count(.//comment)" /></span>
       
           <xsl:if test="ranks">
          | 
           <xsl:call-template name="getString">
             <xsl:with-param name="stringName" select="'Score'"/>
           </xsl:call-template>: 
           <xsl:value-of select="ranks/reputationScore" />
          </xsl:if>
          | <xsl:call-template name="getString">
            <xsl:with-param name="stringName" select="'Vote'"/>
            </xsl:call-template>
            : <a href="./?type=vote&amp;postID={$postID}&amp;value=-1&amp;url={$url}"><img src="css/votesmall-.png" height="12px" style="margin-right:10px"/></a>
          <a href="./?type=vote&amp;postID={$postID}&amp;value=1&amp;url={$url}"> <img src="css/votesmall+.png" height="12px" /></a>
        </span>
        
      </div>
    </div>
    </div>
    <xsl:apply-templates select="comments"/>
    </xsl:for-each>
  </div>
  </div>
  <div id="right">
    <div class="cpad">  
      <xsl:if test="$avatar='true'">
        <div class="wheader f1 f1a">
          <div class="l">
            <div class="t">
              <div class="b">
                <div class="r">
                  <div class="lt">
                    <div class="lb">
                      <div class="rt">
                        <div class="rb wmenu">
                          <div class="avatar">
                            <a href="{$blogURL}" title="{/postView//info/realName}: Blog">
                              <img src="avatar.jpg" alt="{/postView//info/realName}"/>
                            </a>
                            <p><xsl:value-of select="/postView/info/realName" /></p>
                          </div>
                        </div>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </xsl:if>
      <h2><xsl:call-template name="getString">
        <xsl:with-param name="stringName" select="'About author'"/>
      </xsl:call-template></h2>
      <div class="aboutnode">
       <span class="bold"><xsl:call-template name="getString">
        <xsl:with-param name="stringName" select="'Authority'"/>
        </xsl:call-template>: 
      </span> <xsl:value-of select="/postView//info/ranks/authorityScore" />
        <div class="formatted">
          <xsl:copy-of select="/postView//info/about/node()" />
        </div>
      </div>
      <h2><xsl:call-template name="getString">
        <xsl:with-param name="stringName" select="'Tags'"/>
      </xsl:call-template></h2>
      <ul>
      <xsl:for-each select="/postView/post/tags/tag">
        <a href="{blogURL}/?tag={.}"><xsl:value-of select="." /></a>
        <xsl:if test="position() != last()">
            <xsl:text>, </xsl:text>
        </xsl:if>
      </xsl:for-each>
      </ul>
      <xsl:apply-templates select="otherPosts"/>
    </div>
  </div>
</xsl:template>


<xsl:template match="otherPosts">
  <h2><xsl:call-template name="getString">
    <xsl:with-param name="stringName" select="'Other posts'"/>
  </xsl:call-template></h2>
  <ul style="margin-left: 0px;">
    <xsl:for-each select="post[@status='published']">
    <xsl:sort select="date/@timestamp" order="descending"/>
    <li><a href="{$blogURL}/{@ID}-{my:urlpostfix(title)}"> <xsl:value-of select="title" /></a></li>
  </xsl:for-each>
  </ul>
</xsl:template>

<xsl:template match="comments" >
  <div class="reply">
    <a href="{$blogURL}/?type=commentForm&amp;postID={$postID}">Reagovať na článok</a>
  </div>
  <xsl:apply-templates select="comment"/>
</xsl:template>

<xsl:template match="comment" >
  <div class="comment">
    <h3>
      <xsl:value-of select="title" />
    </h3>
    <p>
      <xsl:value-of select="substring(date,9,2)" />.
      <xsl:value-of select="substring(date,6,2)" />.
      <xsl:value-of select="substring(date,1,4)" /><xsl:text> </xsl:text>
      <xsl:value-of select="substring-after(date,'T')" /> | <xsl:if test="author[@guest]">
      <xsl:if test="not(author/text())">Anonym</xsl:if>
        <xsl:value-of select="author" />
      </xsl:if>
      <xsl:if test="author[not(@guest)]">
        <em>
          <a href="http://{author/nick}.{$base}">
            
            <xsl:if test="string-length(author/realName)=0">
              <xsl:value-of select="author/nick" />
            </xsl:if>
            <xsl:value-of select="author/realName" />
          </a>
        </em>
      </xsl:if>
    </p>
    
    <xsl:if test="author[not(@guest)]">
      <a href="http://{author/nick}.{$base}" title="Blog: {author/nick}">
        <img src="./files/{author/nick}/avatar.jpg" height="40px" class="imgRight" alt="Blog: {author/nick}"/>
      </a>
    </xsl:if>
    <div class="formatted"> <xsl:copy-of select="content/node()" /></div>
    <div class="clear"/>
    <div class="reply">
      <a href="{$blogURL}/?type=commentForm&amp;commentID={@ID}&amp;postID={$postID}">Reagovať</a>
      <hr />
    </div>
    <xsl:if test="$loggedUser">
      <xsl:if test="$loggedUserID = $userID">
        <div>
          <form action="index.php?type=deleteComment" method="post" class="frm" onsubmit="return window.confirm('Chcete naozaj zmazať tento komentár?')">
            <input type="hidden" name="postID" value="{$postID}" />
            <input type="hidden" name="commentID" value="{@ID}" />
              <button class="submit"><xsl:call-template name="getString">
                <xsl:with-param name="stringName" select="'Delete'"/>
              </xsl:call-template></button>
          </form>
        </div>
      </xsl:if>
    </xsl:if>
    <xsl:apply-templates select="comment" />
    
  </div>
</xsl:template>

<func:function name="my:urlpostfix">
  <xsl:param name="what" />
  <xsl:variable name="up" select="'ABCDEFGHIJKLMNOPQRSTUVWXYZ'"/>
  <xsl:variable name="lo" select="'abcdefghijklmnopqrstuvwxyz'"/>
  <xsl:variable name="space" select="'_ ?.!:=-()'"/>
  <xsl:variable name="other" select="'          '"/>
  <xsl:variable name="dia" select="'áéíóuýčďľĺňôřšťž'"/>
  <xsl:variable name="nor" select="'aeiouycdllnorstz'"/>
  <xsl:variable name="diab" select="'ÁÉÍÓÚÝČĎĽĹŇÔŘŠŤŽ'"/>
  <xsl:variable name="norb" select="'aeiouycdllnorstz'"/>
  <func:result>
    <xsl:value-of select="
    translate(
      normalize-space(
        translate(
          translate(
       	   translate(
          	  translate(
                $what, $up, $lo
          	  ), $space, $other
        	   ), $dia, $nor
          ), $diab, $norb
    	  )
      ), ' ', '-'
    )" />
  </func:result>
</func:function>

</xsl:stylesheet>