<?xml version="1.0" encoding="utf8"?>
<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:func="http://exslt.org/functions"
                xmlns:date="http://exslt.org/dates-and-times"
                xmlns:math="http://exslt.org/math"
                xmlns:my="http://blog.matfyz.sk"
                exclude-result-prefixes="math xsl"
                extension-element-prefixes="my func date math">
  <xsl:import href="layout.xsl" />
  <xsl:output omit-xml-declaration="no" method="xml" doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd" indent="yes" encoding="utf-8" />
  <xsl:variable name="userID" select='/user/@ID' />
  <xsl:variable name="title" select='/user/blog/title' />
  <xsl:variable name="subtitle" select='/user/info/nick' />
  <xsl:variable name="nick" select='/user/info/nick' />
  <xsl:variable name="blogTitle" select='$title' />
  <xsl:variable name="blogURL" select="concat('http://',$nick,'.',$base)" />
  <xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
  <xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
  <xsl:param name="tag" />
  <xsl:param name="sort" />
  <xsl:param name="order" />
  
  <xsl:template match="/">
    <xsl:apply-imports />
  </xsl:template>
  
  <xsl:template match="/user">
      <span id="activesort" title="date" />
      <span id="activeorder" title="desc" />
      <xsl:variable name="sortOrder">
        <xsl:choose>
          <xsl:when test="$order = 'asc'">ascending</xsl:when>
          <xsl:when test="$order = 'desc'">descending</xsl:when>
          <xsl:otherwise>ascending</xsl:otherwise>
        </xsl:choose>
      </xsl:variable>
      <xsl:variable name="catUrl">
        <xsl:choose>
          <xsl:when test="$tag">?tag=<xsl:value-of select="$tag" /></xsl:when>
          <xsl:otherwise></xsl:otherwise>
        </xsl:choose>
      </xsl:variable>
      <p id="sortList">
        <xsl:call-template name="getString">
          <xsl:with-param name="stringName" select="'Sort by'"/>
        </xsl:call-template>:
        <a href="{$blogURL}/posts?sort=name&amp;order={my:sort('name',$sort,$order)}{$catUrl}" class="{my:sortclass('name',$sort,$order)}">Abecedy</a>
        <a href="{$blogURL}/posts?sort=views&amp;order={my:sort('views',$sort,$order)}{$catUrl}" class="{my:sortclass('views',$sort,$order)}">Počtu zobrazení</a>
        <a href="{$blogURL}/posts?sort=react&amp;order={my:sort('react',$sort,$order)}{$catUrl}" class="{my:sortclass('react',$sort,$order)}">Reakcií</a>
        <a href="{$blogURL}/posts?sort=date&amp;order={my:sort('date',$sort,$order)}{$catUrl}" class="{my:sortclass('date',$sort,$order)}">Dátumu</a>
      </p>
      <div id="posts">
        <div class="tagCloud">
          <a href="./posts"><xsl:call-template name="getString">
            <xsl:with-param name="stringName" select="'All'"/>
          </xsl:call-template> (<xsl:value-of select="count(/user/blog/post)" />)</a>
          <xsl:text>, </xsl:text>
          <xsl:variable name="tags" select="/user/blog/post/tags" />
          <xsl:for-each select="$tags/tag[not(. = preceding::tag)]">
            <xsl:sort select="translate(.,$ucletters,$lcletters)" order="ascending"/>
            <xsl:variable name="tag" select="." />
            <a href="./posts?tag={.}"><xsl:value-of select="."/> (<xsl:value-of select="count(/user/blog/post[.//tag=$tag])" />)</a>
            <xsl:if test="position() != last()">
              <xsl:text>, </xsl:text>
            </xsl:if>
          </xsl:for-each>
        </div>
          <div>
            <form action="{$blogURL}/newpost" method="post" class="frm">
              <fieldset>
                <button class="submit"><xsl:call-template name="getString">
                  <xsl:with-param name="stringName" select="'newPost'"/>
                </xsl:call-template></button>
              </fieldset>
            </form>
          </div>
        <table border="0" cellspacing="1" cellpadding="0" class="table">
          <tr>
            <th><xsl:call-template name="getString">
              <xsl:with-param name="stringName" select="'Title'"/>
            </xsl:call-template></th>
            <th><xsl:call-template name="getString">
              <xsl:with-param name="stringName" select="'Created'"/>
            </xsl:call-template></th>
            <th><xsl:call-template name="getString">
              <xsl:with-param name="stringName" select="'Changed'"/>
            </xsl:call-template></th>
            <th><xsl:call-template name="getString">
              <xsl:with-param name="stringName" select="'Status'"/>
            </xsl:call-template></th>
            <th><xsl:call-template name="getString">
              <xsl:with-param name="stringName" select="'Action'"/>
            </xsl:call-template></th>
          </tr>
          <xsl:choose>
          <xsl:when test="$sort = 'name'">
            <xsl:apply-templates select="blog/post[((tags/tag=$tag) or not($tag)) and contains($lang,@lang)]">
            <xsl:sort select="title" order="{$sortOrder}" />
            <xsl:sort select="@ID" order="descending" data-type="number" />
            </xsl:apply-templates>
          </xsl:when>
          <xsl:when test="$sort = 'views'">
            <xsl:apply-templates select="blog/post[((tags/tag=$tag) or not($tag)) and contains($lang,@lang)]">
            <xsl:sort select="@accessCount" order="{$sortOrder}" data-type="number" />
            <xsl:sort select="@ID" order="descending" data-type="number" />
            </xsl:apply-templates>
          </xsl:when>
          <xsl:when test="$sort = 'react'">
            <xsl:apply-templates select="blog/post[((tags/tag=$tag) or not($tag)) and contains($lang,@lang)]">
            <xsl:sort select="count(.//comment)" order="{$sortOrder}" data-type="number" />
            <xsl:sort select="@ID" order="descending" data-type="number" />
            </xsl:apply-templates>
          </xsl:when>
          <xsl:when test="$sort = 'date'">
            <xsl:apply-templates select="blog/post[((tags/tag=$tag) or not($tag)) and contains($lang,@lang)]">
            <xsl:sort select="date/@timestamp" order="{$sortOrder}" />
            <xsl:sort select="@ID" order="descending" data-type="number" />
            </xsl:apply-templates>
          </xsl:when>
          <xsl:otherwise>
            <xsl:apply-templates select="blog/post[((tags/tag=$tag) or not($tag)) and contains($lang,@lang)]">
            <xsl:sort select="date/@timestamp" order="descending" />
            <xsl:sort select="@ID" order="descending" />
            </xsl:apply-templates>
          </xsl:otherwise>
          </xsl:choose>
        </table>
      </div>
  </xsl:template>
  
  <xsl:template match="post">
    <tr>
      <td><a href="{$blogURL}/{@ID}"><xsl:value-of select="title" /></a></td>
      <td><xsl:value-of select="substring(date,9,2)" />.
        <xsl:value-of select="substring(date,6,2)" />.
        <xsl:value-of select="substring(date,1,4)" /><xsl:text> </xsl:text>
        <xsl:value-of select="substring(date,12,2)" />:<xsl:value-of select="substring(date,15,2)" /></td>
      <td>
        <xsl:if test="lastUpdate"><xsl:value-of select="substring(lastUpdate,9,2)" />.
          <xsl:value-of select="substring(lastUpdate,6,2)" />.
          <xsl:value-of select="substring(lastUpdate,1,4)" /><xsl:text> </xsl:text>
          <xsl:value-of select="substring(lastUpdate,12,2)" />:<xsl:value-of select="substring(lastUpdate,15,2)" />
        </xsl:if> </td>
      <td>
        <xsl:call-template name="getString">
          <xsl:with-param name="stringName" select="@status"/>
        </xsl:call-template>
      </td>
      <td><xsl:if test="$loggedUser">
        <xsl:if test="$loggedUserID = $userID">
            <form action="{$blogURL}/?type=editPostForm" method="get" class="frm">
              <fieldset>
                <input type="hidden" name="type" value="editPostForm" />
                <input type="hidden" name="userID" value="{$userID}" />
                <input type="hidden" name="postID" value="{@ID}" />
                <button class="submit"><xsl:call-template name="getString">
                  <xsl:with-param name="stringName" select="'Edit'"/>
                </xsl:call-template></button>
              </fieldset>
            </form>
            <!-- Stavy -->
            <xsl:choose>
              <xsl:when test="@status = 'published'">
                <form action="{$blogURL}/?type=changePostStatus" method="post" class="frm" onsubmit="return window.confirm('Chcete naozaj stiahnuť tento príspevok?')">
                  <fieldset>
                    <input type="hidden" name="status" value="held" />
                    <input type="hidden" name="type" value="deletePost" />
                    <input type="hidden" name="postID" value="{@ID}" />
                    <button class="submit"><xsl:call-template name="getString">
                      <xsl:with-param name="stringName" select="'Held'"/>
                    </xsl:call-template></button>
                  </fieldset>
                </form>
              </xsl:when>
              <xsl:when test="@status = 'held' or @status='draft'">
                <form action="{$blogURL}/?type=changePostStatus" method="post" class="frm" onsubmit="return window.confirm('Chcete naozaj publikovať tento príspevok?')">
                  <fieldset>
                    <input type="hidden" name="status" value="published" />
                    <input type="hidden" name="type" value="deletePost" />
                    <input type="hidden" name="postID" value="{@ID}" />
                    <button class="submit"><xsl:call-template name="getString">
                      <xsl:with-param name="stringName" select="'Publish'"/>
                    </xsl:call-template></button>
                  </fieldset>
                </form>
              </xsl:when>
            </xsl:choose>
            
            <form action="{$blogURL}/?type=deletePost" method="post" class="frm" onsubmit="return window.confirm('Chcete naozaj zmazať tento príspevok?')">
              <fieldset>
                <input type="hidden" name="type" value="deletePost" />
                <input type="hidden" name="userID" value="{$userID}" />
                <input type="hidden" name="postID" value="{@ID}" />
                <xsl:variable name="deleteQuestion"><xsl:call-template name="getString">
                  <xsl:with-param name="stringName" select="'postDeleteQuestion'"/>
                </xsl:call-template></xsl:variable>
                <button class="submit" onclick="return confirm('{$deleteQuestion}');"><xsl:call-template name="getString">
                  <xsl:with-param name="stringName" select="'Delete'"/>
                </xsl:call-template></button>
               </fieldset>
            </form>
        </xsl:if>
      </xsl:if></td>
    </tr>
  </xsl:template>
  
<func:function name="my:sort">
  <xsl:param name="what" />
  <xsl:param name="sort" />
  <xsl:param name="order" />
  <func:result>
  <xsl:choose>
    <xsl:when test="$what = $sort and $order = 'asc'">desc</xsl:when>
    <xsl:when test="$what = $sort and $order = 'desc'">asc</xsl:when>
    <xsl:otherwise>desc</xsl:otherwise>
  </xsl:choose>
  </func:result>
</func:function>

<func:function name="my:sortclass">
  <xsl:param name="what" />
  <xsl:param name="sort" />
  <xsl:param name="order" />
  <func:result>
  <xsl:choose>
    <xsl:when test="$what = 'date' and $order = ''">desc</xsl:when>
    <xsl:when test="$what = $sort and $order = 'asc'">asc</xsl:when>
    <xsl:when test="$what = $sort and $order = 'desc'">desc</xsl:when>
    <xsl:otherwise></xsl:otherwise>
  </xsl:choose>
  </func:result>
</func:function>
  
</xsl:stylesheet>